{/*SDOC*************************************************************

  Module: VCTRAN32.pas

  Copyright (C) 2022 Gold Run Partners, Inc.  All rights reserved.

  Revision Date: 6 Feb 2022

*************************************************************EDOC*/}

unit VCTRAN32;

interface

uses Windows, VCType32;

function VCLoadVCTRAN32: boolean;
procedure VCFreeVCTRAN32;
procedure VCAcadBlockRead (pName: PAnsiChar); stdcall;
procedure VCAcadRead (pN: PAnsiChar); stdcall;
procedure VCAcadReadNoPaint (pNameStart: PAnsiChar); stdcall;
procedure VCAcadReadWith3D (pName: PAnsiChar); stdcall;
procedure VCAcadWriteDWG (pN: PAnsiChar); stdcall;
procedure VCAcadWriteDXF (pN: PAnsiChar); stdcall;
procedure VCLoadDrawing (var iError: SmallInt; pName: PAnsiChar; iFileType: SmallInt); stdcall;
procedure VCMergeDrawing (var iError: SmallInt; pName: PAnsiChar; iFileType: SmallInt); stdcall;
procedure VCMergeDrawingNoPaint (var iError: SmallInt; pInputName: PAnsiChar; iFileType: SmallInt); stdcall;
procedure VCSaveDrawing (var iError: SmallInt; pName: PAnsiChar; iFileType: SmallInt; tfSaveSelected: WordBool); stdcall;
procedure VCWriteMetafile (pName: PAnsiChar; iFileType: SmallInt; tfSelectedOnly: WordBool); stdcall;
procedure VCPlaceMetafileOnClipboard (var iError: SmallInt; tfSelectedOnly: WordBool); stdcall;
procedure VCSaveAll (var iError: SmallInt); stdcall;
function VCGetCursorPos (var pPoint: TPoint): LongBool; stdcall;
function VCGetIniString (szString: PAnsiChar; iSize: LongWord; szFile: PAnsiChar; szSection: PAnsiChar; szKey: PAnsiChar): LongWord; stdcall;
function VCGetIniKeyNames (szString: PAnsiChar; iSize: LongWord; szFile: PAnsiChar; szSection: PAnsiChar): LongWord; stdcall;
function VCGetIniSectionNames (szString: PAnsiChar; iSize: LongWord; szFile: PAnsiChar): LongWord; stdcall;
function VCWriteIniString (szString: PAnsiChar; szFile: PAnsiChar; szSection: PAnsiChar; szKey: PAnsiChar): LongBool; stdcall;
function VCGetVcaddIniString (szString: PAnsiChar; iSize: LongWord; szSection: PAnsiChar; szKey: PAnsiChar): LongWord; stdcall;
function VCGetVcaddIniKeyNames (szString: PAnsiChar; iSize: LongWord; szSection: PAnsiChar): LongWord; stdcall;
function VCGetVcaddIniSectionNames (szString: PAnsiChar; iSize: LongWord): LongWord; stdcall;
function VCWriteVcaddIniString (szString: PAnsiChar; szSection: PAnsiChar; szKey: PAnsiChar): LongBool; stdcall;
function VCOnKeyDown (hWnd: THandle; nChar: LongWord; nRepCnt: LongWord; nFlags: LongWord): LongBool; stdcall;
function VCOnChar (hWnd: THandle; nChar: LongWord; nRepCnt: LongWord; nFlags: LongWord): LongBool; stdcall;
function VCOnLButtonDown (hWnd: THandle; nFlags: LongWord; x: LongInt; y: LongInt): LongBool; stdcall;
function VCOnLButtonDblClk (hWnd: THandle; nFlags: LongWord; x: LongInt; y: LongInt): LongBool; stdcall;
function VCOnLButtonUp (hWnd: THandle; nFlags: LongWord; x: LongInt; y: LongInt): LongBool; stdcall;
function VCOnMButtonDown (hWnd: THandle; nFlags: LongWord; x: LongInt; y: LongInt): LongBool; stdcall;
function VCOnMButtonUp (hWnd: THandle; nFlags: LongWord; x: LongInt; y: LongInt): LongBool; stdcall;
function VCOnRButtonDown (hWnd: THandle; nFlags: LongWord; x: LongInt; y: LongInt): LongBool; stdcall;
function VCOnRButtonUp (hWnd: THandle; nFlags: LongWord; x: LongInt; y: LongInt): LongBool; stdcall;
function VCOnXButtonDown (wParam : LongWord; lParam: LongInt): LongBool; stdcall;
function VCOnMouseMove (hWnd: THandle; nFlags: LongWord; x: LongInt; y: LongInt): LongBool; stdcall;
function VCOnNcMouseMove (hWnd: THandle; nFlags: LongWord; x: LongInt; y: LongInt): LongBool; stdcall;
function VCOnMouseWheel (hWnd: THandle; nFlags: LongWord; iDelta: SmallInt; x: LongInt; y: LongInt): LongBool; stdcall;
function VCOnPreTranslateMessage (var pMsg: MSG): LongBool; stdcall;
procedure VCOnSize (hWnd: THandle; nType: LongWord; cx: LongInt; cy: LongInt); stdcall;
procedure VCOnMove (hWnd: THandle; cx: LongInt; cy: LongInt); stdcall;

implementation

var hInst: THandle;

function VCLoadVCTRAN32: boolean;
begin
  hInst := LoadLibrary('VCTRAN32.DLL');
  result := hInst <> 0;
end;

procedure VCFreeVCTRAN32;
begin
  if hInst <> 0 then
    FreeLibrary(hInst);
end;

procedure VCAcadBlockRead (pName: PAnsiChar);
type TVCProc = procedure (pName: PAnsiChar); stdcall;
var aproc: TVCProc;
begin
  if hInst <> 0 then
  begin
    @aproc := GetProcAddress(hInst, 'VCAcadBlockRead');
    if @aproc <> nil then
      aproc(pName);
  end;
end;

procedure VCAcadRead (pN: PAnsiChar);
type TVCProc = procedure (pN: PAnsiChar); stdcall;
var aproc: TVCProc;
begin
  if hInst <> 0 then
  begin
    @aproc := GetProcAddress(hInst, 'VCAcadRead');
    if @aproc <> nil then
      aproc(pN);
  end;
end;

procedure VCAcadReadNoPaint (pNameStart: PAnsiChar);
type TVCProc = procedure (pNameStart: PAnsiChar); stdcall;
var aproc: TVCProc;
begin
  if hInst <> 0 then
  begin
    @aproc := GetProcAddress(hInst, 'VCAcadReadNoPaint');
    if @aproc <> nil then
      aproc(pNameStart);
  end;
end;

procedure VCAcadReadWith3D (pName: PAnsiChar);
type TVCProc = procedure (pName: PAnsiChar); stdcall;
var aproc: TVCProc;
begin
  if hInst <> 0 then
  begin
    @aproc := GetProcAddress(hInst, 'VCAcadReadWith3D');
    if @aproc <> nil then
      aproc(pName);
  end;
end;

procedure VCAcadWriteDWG (pN: PAnsiChar);
type TVCProc = procedure (pN: PAnsiChar); stdcall;
var aproc: TVCProc;
begin
  if hInst <> 0 then
  begin
    @aproc := GetProcAddress(hInst, 'VCAcadWriteDWG');
    if @aproc <> nil then
      aproc(pN);
  end;
end;

procedure VCAcadWriteDXF (pN: PAnsiChar);
type TVCProc = procedure (pN: PAnsiChar); stdcall;
var aproc: TVCProc;
begin
  if hInst <> 0 then
  begin
    @aproc := GetProcAddress(hInst, 'VCAcadWriteDXF');
    if @aproc <> nil then
      aproc(pN);
  end;
end;

procedure VCLoadDrawing (var iError: SmallInt; pName: PAnsiChar; iFileType: SmallInt);
type TVCProc = procedure (var iError: SmallInt; pName: PAnsiChar; iFileType: SmallInt); stdcall;
var aproc: TVCProc;
begin
  if hInst <> 0 then
  begin
    @aproc := GetProcAddress(hInst, 'VCLoadDrawing');
    if @aproc <> nil then
      aproc(iError, pName, iFileType);
  end;
end;

procedure VCMergeDrawing (var iError: SmallInt; pName: PAnsiChar; iFileType: SmallInt);
type TVCProc = procedure (var iError: SmallInt; pName: PAnsiChar; iFileType: SmallInt); stdcall;
var aproc: TVCProc;
begin
  if hInst <> 0 then
  begin
    @aproc := GetProcAddress(hInst, 'VCMergeDrawing');
    if @aproc <> nil then
      aproc(iError, pName, iFileType);
  end;
end;

procedure VCMergeDrawingNoPaint (var iError: SmallInt; pInputName: PAnsiChar; iFileType: SmallInt);
type TVCProc = procedure (var iError: SmallInt; pInputName: PAnsiChar; iFileType: SmallInt); stdcall;
var aproc: TVCProc;
begin
  if hInst <> 0 then
  begin
    @aproc := GetProcAddress(hInst, 'VCMergeDrawingNoPaint');
    if @aproc <> nil then
      aproc(iError, pInputName, iFileType);
  end;
end;

procedure VCSaveDrawing (var iError: SmallInt; pName: PAnsiChar; iFileType: SmallInt; tfSaveSelected: WordBool);
type TVCProc = procedure (var iError: SmallInt; pName: PAnsiChar; iFileType: SmallInt; tfSaveSelected: WordBool); stdcall;
var aproc: TVCProc;
begin
  if hInst <> 0 then
  begin
    @aproc := GetProcAddress(hInst, 'VCSaveDrawing');
    if @aproc <> nil then
      aproc(iError, pName, iFileType, tfSaveSelected);
  end;
end;

procedure VCWriteMetafile (pName: PAnsiChar; iFileType: SmallInt; tfSelectedOnly: WordBool);
type TVCProc = procedure (pName: PAnsiChar; iFileType: SmallInt; tfSelectedOnly: WordBool); stdcall;
var aproc: TVCProc;
begin
  if hInst <> 0 then
  begin
    @aproc := GetProcAddress(hInst, 'VCWriteMetafile');
    if @aproc <> nil then
      aproc(pName, iFileType, tfSelectedOnly);
  end;
end;

procedure VCPlaceMetafileOnClipboard (var iError: SmallInt; tfSelectedOnly: WordBool);
type TVCProc = procedure (var iError: SmallInt; tfSelectedOnly: WordBool); stdcall;
var aproc: TVCProc;
begin
  if hInst <> 0 then
  begin
    @aproc := GetProcAddress(hInst, 'VCPlaceMetafileOnClipboard');
    if @aproc <> nil then
      aproc(iError, tfSelectedOnly);
  end;
end;

procedure VCSaveAll (var iError: SmallInt);
type TVCProc = procedure (var iError: SmallInt); stdcall;
var aproc: TVCProc;
begin
  if hInst <> 0 then
  begin
    @aproc := GetProcAddress(hInst, 'VCSaveAll');
    if @aproc <> nil then
      aproc(iError);
  end;
end;

function VCGetCursorPos (var pPoint: TPoint): LongBool;
type TVCProc = function (var pPoint: TPoint): LongBool; stdcall;
var aproc: TVCProc;
begin
  result := LongBool(0);
  if hInst <> 0 then
  begin
    @aproc := GetProcAddress(hInst, 'VCGetCursorPos');
    if @aproc <> nil then
      result := aproc(pPoint);
  end;
end;

function VCGetIniString (szString: PAnsiChar; iSize: LongWord; szFile: PAnsiChar; szSection: PAnsiChar; szKey: PAnsiChar): LongWord;
type TVCProc = function (szString: PAnsiChar; iSize: LongWord; szFile: PAnsiChar; szSection: PAnsiChar; szKey: PAnsiChar): LongWord; stdcall;
var aproc: TVCProc;
begin
  result := LongWord(0);
  if hInst <> 0 then
  begin
    @aproc := GetProcAddress(hInst, 'VCGetIniString');
    if @aproc <> nil then
      result := aproc(szString, iSize, szFile, szSection, szKey);
  end;
end;

function VCGetIniKeyNames (szString: PAnsiChar; iSize: LongWord; szFile: PAnsiChar; szSection: PAnsiChar): LongWord;
type TVCProc = function (szString: PAnsiChar; iSize: LongWord; szFile: PAnsiChar; szSection: PAnsiChar): LongWord; stdcall;
var aproc: TVCProc;
begin
  result := LongWord(0);
  if hInst <> 0 then
  begin
    @aproc := GetProcAddress(hInst, 'VCGetIniKeyNames');
    if @aproc <> nil then
      result := aproc(szString, iSize, szFile, szSection);
  end;
end;

function VCGetIniSectionNames (szString: PAnsiChar; iSize: LongWord; szFile: PAnsiChar): LongWord;
type TVCProc = function (szString: PAnsiChar; iSize: LongWord; szFile: PAnsiChar): LongWord; stdcall;
var aproc: TVCProc;
begin
  result := LongWord(0);
  if hInst <> 0 then
  begin
    @aproc := GetProcAddress(hInst, 'VCGetIniSectionNames');
    if @aproc <> nil then
      result := aproc(szString, iSize, szFile);
  end;
end;

function VCWriteIniString (szString: PAnsiChar; szFile: PAnsiChar; szSection: PAnsiChar; szKey: PAnsiChar): LongBool;
type TVCProc = function (szString: PAnsiChar; szFile: PAnsiChar; szSection: PAnsiChar; szKey: PAnsiChar): LongBool; stdcall;
var aproc: TVCProc;
begin
  result := LongBool(0);
  if hInst <> 0 then
  begin
    @aproc := GetProcAddress(hInst, 'VCWriteIniString');
    if @aproc <> nil then
      result := aproc(szString, szFile, szSection, szKey);
  end;
end;

function VCGetVcaddIniString (szString: PAnsiChar; iSize: LongWord; szSection: PAnsiChar; szKey: PAnsiChar): LongWord;
type TVCProc = function (szString: PAnsiChar; iSize: LongWord; szSection: PAnsiChar; szKey: PAnsiChar): LongWord; stdcall;
var aproc: TVCProc;
begin
  result := LongWord(0);
  if hInst <> 0 then
  begin
    @aproc := GetProcAddress(hInst, 'VCGetVcaddIniString');
    if @aproc <> nil then
      result := aproc(szString, iSize, szSection, szKey);
  end;
end;

function VCGetVcaddIniKeyNames (szString: PAnsiChar; iSize: LongWord; szSection: PAnsiChar): LongWord;
type TVCProc = function (szString: PAnsiChar; iSize: LongWord; szSection: PAnsiChar): LongWord; stdcall;
var aproc: TVCProc;
begin
  result := LongWord(0);
  if hInst <> 0 then
  begin
    @aproc := GetProcAddress(hInst, 'VCGetVcaddIniKeyNames');
    if @aproc <> nil then
      result := aproc(szString, iSize, szSection);
  end;
end;

function VCGetVcaddIniSectionNames (szString: PAnsiChar; iSize: LongWord): LongWord;
type TVCProc = function (szString: PAnsiChar; iSize: LongWord): LongWord; stdcall;
var aproc: TVCProc;
begin
  result := LongWord(0);
  if hInst <> 0 then
  begin
    @aproc := GetProcAddress(hInst, 'VCGetVcaddIniSectionNames');
    if @aproc <> nil then
      result := aproc(szString, iSize);
  end;
end;

function VCWriteVcaddIniString (szString: PAnsiChar; szSection: PAnsiChar; szKey: PAnsiChar): LongBool;
type TVCProc = function (szString: PAnsiChar; szSection: PAnsiChar; szKey: PAnsiChar): LongBool; stdcall;
var aproc: TVCProc;
begin
  result := LongBool(0);
  if hInst <> 0 then
  begin
    @aproc := GetProcAddress(hInst, 'VCWriteVcaddIniString');
    if @aproc <> nil then
      result := aproc(szString, szSection, szKey);
  end;
end;

function VCOnKeyDown (hWnd: THandle; nChar: LongWord; nRepCnt: LongWord; nFlags: LongWord): LongBool;
type TVCProc = function (hWnd: THandle; nChar: LongWord; nRepCnt: LongWord; nFlags: LongWord): LongBool; stdcall;
var aproc: TVCProc;
begin
  result := LongBool(0);
  if hInst <> 0 then
  begin
    @aproc := GetProcAddress(hInst, 'VCOnKeyDown');
    if @aproc <> nil then
      result := aproc(hWnd, nChar, nRepCnt, nFlags);
  end;
end;

function VCOnChar (hWnd: THandle; nChar: LongWord; nRepCnt: LongWord; nFlags: LongWord): LongBool;
type TVCProc = function (hWnd: THandle; nChar: LongWord; nRepCnt: LongWord; nFlags: LongWord): LongBool; stdcall;
var aproc: TVCProc;
begin
  result := LongBool(0);
  if hInst <> 0 then
  begin
    @aproc := GetProcAddress(hInst, 'VCOnChar');
    if @aproc <> nil then
      result := aproc(hWnd, nChar, nRepCnt, nFlags);
  end;
end;

function VCOnLButtonDown (hWnd: THandle; nFlags: LongWord; x: LongInt; y: LongInt): LongBool;
type TVCProc = function (hWnd: THandle; nFlags: LongWord; x: LongInt; y: LongInt): LongBool; stdcall;
var aproc: TVCProc;
begin
  result := LongBool(0);
  if hInst <> 0 then
  begin
    @aproc := GetProcAddress(hInst, 'VCOnLButtonDown');
    if @aproc <> nil then
      result := aproc(hWnd, nFlags, x, y);
  end;
end;

function VCOnLButtonDblClk (hWnd: THandle; nFlags: LongWord; x: LongInt; y: LongInt): LongBool;
type TVCProc = function (hWnd: THandle; nFlags: LongWord; x: LongInt; y: LongInt): LongBool; stdcall;
var aproc: TVCProc;
begin
  result := LongBool(0);
  if hInst <> 0 then
  begin
    @aproc := GetProcAddress(hInst, 'VCOnLButtonDblClk');
    if @aproc <> nil then
      result := aproc(hWnd, nFlags, x, y);
  end;
end;

function VCOnLButtonUp (hWnd: THandle; nFlags: LongWord; x: LongInt; y: LongInt): LongBool;
type TVCProc = function (hWnd: THandle; nFlags: LongWord; x: LongInt; y: LongInt): LongBool; stdcall;
var aproc: TVCProc;
begin
  result := LongBool(0);
  if hInst <> 0 then
  begin
    @aproc := GetProcAddress(hInst, 'VCOnLButtonUp');
    if @aproc <> nil then
      result := aproc(hWnd, nFlags, x, y);
  end;
end;

function VCOnMButtonDown (hWnd: THandle; nFlags: LongWord; x: LongInt; y: LongInt): LongBool;
type TVCProc = function (hWnd: THandle; nFlags: LongWord; x: LongInt; y: LongInt): LongBool; stdcall;
var aproc: TVCProc;
begin
  result := LongBool(0);
  if hInst <> 0 then
  begin
    @aproc := GetProcAddress(hInst, 'VCOnMButtonDown');
    if @aproc <> nil then
      result := aproc(hWnd, nFlags, x, y);
  end;
end;

function VCOnMButtonUp (hWnd: THandle; nFlags: LongWord; x: LongInt; y: LongInt): LongBool;
type TVCProc = function (hWnd: THandle; nFlags: LongWord; x: LongInt; y: LongInt): LongBool; stdcall;
var aproc: TVCProc;
begin
  result := LongBool(0);
  if hInst <> 0 then
  begin
    @aproc := GetProcAddress(hInst, 'VCOnMButtonUp');
    if @aproc <> nil then
      result := aproc(hWnd, nFlags, x, y);
  end;
end;

function VCOnRButtonDown (hWnd: THandle; nFlags: LongWord; x: LongInt; y: LongInt): LongBool;
type TVCProc = function (hWnd: THandle; nFlags: LongWord; x: LongInt; y: LongInt): LongBool; stdcall;
var aproc: TVCProc;
begin
  result := LongBool(0);
  if hInst <> 0 then
  begin
    @aproc := GetProcAddress(hInst, 'VCOnRButtonDown');
    if @aproc <> nil then
      result := aproc(hWnd, nFlags, x, y);
  end;
end;

function VCOnRButtonUp (hWnd: THandle; nFlags: LongWord; x: LongInt; y: LongInt): LongBool;
type TVCProc = function (hWnd: THandle; nFlags: LongWord; x: LongInt; y: LongInt): LongBool; stdcall;
var aproc: TVCProc;
begin
  result := LongBool(0);
  if hInst <> 0 then
  begin
    @aproc := GetProcAddress(hInst, 'VCOnRButtonUp');
    if @aproc <> nil then
      result := aproc(hWnd, nFlags, x, y);
  end;
end;

function VCOnXButtonDown (wParam : LongWord; lParam: LongInt): LongBool;
type TVCProc = function (wParam : LongWord; lParam: LongInt): LongBool; stdcall;
var aproc: TVCProc;
begin
  result := LongBool(0);
  if hInst <> 0 then
  begin
    @aproc := GetProcAddress(hInst, 'VCOnXButtonDown');
    if @aproc <> nil then
      result := aproc(wParam , lParam);
  end;
end;

function VCOnMouseMove (hWnd: THandle; nFlags: LongWord; x: LongInt; y: LongInt): LongBool;
type TVCProc = function (hWnd: THandle; nFlags: LongWord; x: LongInt; y: LongInt): LongBool; stdcall;
var aproc: TVCProc;
begin
  result := LongBool(0);
  if hInst <> 0 then
  begin
    @aproc := GetProcAddress(hInst, 'VCOnMouseMove');
    if @aproc <> nil then
      result := aproc(hWnd, nFlags, x, y);
  end;
end;

function VCOnNcMouseMove (hWnd: THandle; nFlags: LongWord; x: LongInt; y: LongInt): LongBool;
type TVCProc = function (hWnd: THandle; nFlags: LongWord; x: LongInt; y: LongInt): LongBool; stdcall;
var aproc: TVCProc;
begin
  result := LongBool(0);
  if hInst <> 0 then
  begin
    @aproc := GetProcAddress(hInst, 'VCOnNcMouseMove');
    if @aproc <> nil then
      result := aproc(hWnd, nFlags, x, y);
  end;
end;

function VCOnMouseWheel (hWnd: THandle; nFlags: LongWord; iDelta: SmallInt; x: LongInt; y: LongInt): LongBool;
type TVCProc = function (hWnd: THandle; nFlags: LongWord; iDelta: SmallInt; x: LongInt; y: LongInt): LongBool; stdcall;
var aproc: TVCProc;
begin
  result := LongBool(0);
  if hInst <> 0 then
  begin
    @aproc := GetProcAddress(hInst, 'VCOnMouseWheel');
    if @aproc <> nil then
      result := aproc(hWnd, nFlags, iDelta, x, y);
  end;
end;

function VCOnPreTranslateMessage (var pMsg: MSG): LongBool;
type TVCProc = function (var pMsg: MSG): LongBool; stdcall;
var aproc: TVCProc;
begin
  result := LongBool(0);
  if hInst <> 0 then
  begin
    @aproc := GetProcAddress(hInst, 'VCOnPreTranslateMessage');
    if @aproc <> nil then
      result := aproc(pMsg);
  end;
end;

procedure VCOnSize (hWnd: THandle; nType: LongWord; cx: LongInt; cy: LongInt);
type TVCProc = procedure (hWnd: THandle; nType: LongWord; cx: LongInt; cy: LongInt); stdcall;
var aproc: TVCProc;
begin
  if hInst <> 0 then
  begin
    @aproc := GetProcAddress(hInst, 'VCOnSize');
    if @aproc <> nil then
      aproc(hWnd, nType, cx, cy);
  end;
end;

procedure VCOnMove (hWnd: THandle; cx: LongInt; cy: LongInt);
type TVCProc = procedure (hWnd: THandle; cx: LongInt; cy: LongInt); stdcall;
var aproc: TVCProc;
begin
  if hInst <> 0 then
  begin
    @aproc := GetProcAddress(hInst, 'VCOnMove');
    if @aproc <> nil then
      aproc(hWnd, cx, cy);
  end;
end;

end.
