{/*SDOC*************************************************************

  Module:	VCType32.pas

  Copyright (C) 2022 Gold Run Partners, Inc.  All rights reserved.

  Revision Date: 9 January 2022

*************************************************************EDOC*/}

unit VCType32;

interface

uses Windows;

{Visual CADD Global Global Constants}

{Entity Kinds}
{function VCGetCurrentEntityKind (var iError: SmallInt): SmallInt; stdcall;}
{Reserve 1-100 for 2D kinds}
Const
entUNKNOWN = 0;
entLINE2D = 1;
entARC2D = 2;
entCIRCLE2D = 3;
entELLIPSE2D = 4;
entBEZIER2D = 5;
entPOINT2D = 6;
entSYMBOL2D = 7;
entTEXT2D = 8;
entDIMLINEAR2D = 9;
entDIMANGULAR2D = 10;
entDIMRADIAL2D = 11;
entDIMDIAMETER2D = 12;
entFILL2D = 13;
entHATCH2D = 14;
entATTRIBUTE2D = 15;
entINTERPCURV2D = 16;
entMINTERPCURV2D = 17;
entELLIPTICALARC2D = 18;
entCONTINUOUSLINE2D = 19;
entCONTINUOUSBEZIER2D = 20;
entLEADER2D = 21;
entREFFRAME2D = 22;
entORDDIM2D = 23;
entIMAGE2D = 24; {Added version 6.0.0}
entMULTILINE2D = 25; {Added version 6.0.0}

{Reserve 101-200 for 3D kinds}
entPOLYGON3D = 101;
entPOINT3D = 102;
entLINE3D = 103;
entSYMBOL3D = 104;
entCONTINUOUSLINE3D = 105;

{procedure VCScreenToWorld2DBP  (var iError: SmallInt; var ipScreen: iPoint2D; var dpWorld: Point2D); stdcall;
 ipScreen = }
Type
iPoint2D=record
	x: LongInt;
	y: LongInt;
end;

{procedure VCDigPointBP  (var lpt: lPoint2D; bButtonNum: SmallInt; bButtonState: SmallInt); stdcall;
 lpt = }
Type
lPoint2D=record
	x: LongInt;
	y: LongInt;
end;

{procedure VCAddLineEntityBP (var iError: SmallInt; iSymbolIndex: SmallInt; var dpP0: Point2D; var dpP1: Point2D); stdcall;
 dpP0 = }
Type
Point2D=record
	x: Double;
	y: Double;
end;

{procedure VCAddLine3D (var iError: SmallInt; iSymbolIndex: SmallInt; var dpP0: Point3D; var dpP1: Point3D); stdcall;
 dpP0 = }
Type
Point3D=record
	x: Double;
	y: Double;
	z: Double;
end;

{procedure VCChangeSelected (var ea: EAttr); stdcall;
 ea = }
Type
EAttr=record
	color: SmallInt;
	layer: SmallInt;
	linetype: SmallInt;
	linewidth: SmallInt;
	fWidth: Single;
	bByLayerFlag: Byte;
end;

{Bitwise flags that can be "OR"ed together for the bByLayerFlag member of the EAttr Struct}
const
COLORBYLAYER = 1;
TYPEBYLAYER = 2;
WIDTHBYLAYER = 4;
RESERVEBYLAYER = 8;

{======================================================================================
 Defines for VCSetAlertApp, VCSetAlertAppEx, VCSetAlertAppDll & VCSetAlertAppDllEx
 procedure VCSetAlertAppDllEx (var iError: SmallInt; DllName: PAnsiChar; NativeCmd: PAnsiChar; iCode0: LongInt; iCode1: LongInt); stdcall;

 iCode0 = ALERT_APP_....
 Code1 = ALERT_APP_EX_.....
 These values can be bit-wise "OR"ed together.
 Example:
 VCSetAlertAppDllEx(iError, DllName, NativeCmd, iCode0, iCode1);
 iCode0 = ALERT_APP_WORLD_CLOSE | ALERT_APP_UTOOL_MOUSEMOVE
 iCode1 = ALERT_APP_EX_WORLD_ACTIVATE


 The ALERT_APP_..._DLL defines are the DLL function name postfixs when using
 VCSetAlertAppDll(...) and VCSetAlertAppDllEx(...). They are seperated from the
 NativeCmd parameter by a '_'.
 Example:
 NativeCmd = "MyFunction"
 iCode0 = ALERT_APP_UTOOL_MOUSEDOWN | ALERT_APP_UTOOL_MOUSEMOVE
 You need to define the following functions in your DLL:
 void WINAPI MyFunction_MouseDown( WPARAM, LPARAM);
 void WINAPI MyFunction_MouseMove( WPARAM, LPARAM);

 The ALERT_..._CHARCODE defines values are sent to your application as the wParam
 parameters of a WM_CHAR message when using VCSetAlertApp(...) and VCSetAlertAppEx(...).

 The ALERT_APP_... HEX value defines are for the iCode0
 The ALERT_APP_EX_... HEX value defines are for the iCode1
======================================================================================}

{Added version 6.0.0}
Type
AlertMSG = record
	hwnd: LongWord;
	message: LongWord;
	wParam: LongWord;
	lParam: LongInt;
	dwUnused: LongWord;
	lResult: LongInt;
	lResultFlag: LongInt;
end;

{VCAlertApp Codes}
Const
ALERT_APP_ALL = $0;
ALERT_APP_NONE = $80000000;

ALERT_APP_UTOOL_MOUSEDOWN = $1;
ALERT_APP_UTOOL_MOUSEDOWN_DLL = 'MouseDown';

ALERT_APP_UTOOL_MOUSEMOVE = $2;
ALERT_APP_UTOOL_MOUSEMOVE_DLL = 'MouseMove';

ALERT_APP_UTOOL_ABORT = $4;
ALERT_APP_UTOOL_ABORT_DLL = 'Abort';

ALERT_APP_CMDLINE_CHAR = $8;
ALERT_APP_CMDLINE_CHAR_DLL = 'Char';

ALERT_APP_CLOSE = $10;
ALERT_APP_CLOSE_DLL = 'AppClose';

ALERT_APP_UTOOL_PENUP = $20;
ALERT_APP_UTOOL_PENUP_DLL = 'PenUp';
ALERT_PENUP_CHARCODE = 252;

ALERT_APP_WORLD_CLOSE = $40;
ALERT_APP_WORLD_CLOSE_DLL = 'DrawingClose';
ALERT_APP_WORLD_CLOSE_CHARCODE = 253;

ALERT_APP_UTOOL_ERASERUBBER = $80;
ALERT_APP_UTOOL_ERASERUBBER_DLL = 'EraseRubber';
ALERT_UTOOL_ERASERUBBER_CHARCODE = 255;

ALERT_APP_TOOL_COMPLETE = $100;
ALERT_APP_TOOL_COMPLETE_DLL = 'ToolComplete';
ALERT_TOOL_COMPLETE_CHARCODE = 254;
{Added version 4.0.0
 Added an encoded lParam which is sent with the alert 
 LOWORD = the ID of the tool completing. See CmdID.h
 HIGHWORD = the tool type. See Visual CADD Tool Types.}

ALERT_APP_UTOOL_INIT = $200;
ALERT_APP_UTOOL_INIT_DLL = 'Init';
ALERT_UTOOL_INIT_CHARCODE = 251;

ALERT_APP_UTOOL_TERMINATE = $400;
ALERT_APP_UTOOL_TERMINATE_DLL = 'Terminate';
ALERT_UTOOL_TERMINATE_CHARCODE = 250;

ALERT_APP_FRAME_CLOSE = $800;
ALERT_APP_FRAME_CLOSE_DLL = 'FrameClose';
ALERT_FRAME_CLOSE_CHARCODE = 249;

ALERT_APP_FRAME_RESIZE = $1000;
ALERT_APP_FRAME_RESIZE_DLL = 'FrameResize';
ALERT_FRAME_RESIZE_CHARCODE = 248;

ALERT_APP_ENTITY_ERASED = $2000;
ALERT_APP_ENTITY_ERASED_DLL = 'EntityErased';
ALERT_APP_ENTITY_ERASED_CHARCODE = 247;

ALERT_APP_ENTITY_SELECT_CHANGE = $4000;
ALERT_APP_ENTITY_SELECT_CHANGE_DLL = 'EntitySelectChange';
ALERT_APP_ENTITY_SELECT_CHANGE_CHARCODE = 246;

ALERT_APP_ACTIVATE = $8000;
ALERT_APP_ACTIVATE_DLL = 'Activate';
ALERT_APP_ACTIVATE_CHARCODE = 245;

ALERT_APP_DEACTIVATE = $10000;
ALERT_APP_DEACTIVATE_DLL = 'DeActivate';
ALERT_APP_DEACTIVATE_CHARCODE = 244;

ALERT_APP_UTOOL_MOUSEUP = $20000;
ALERT_APP_UTOOL_MOUSEUP_DLL = 'MouseUp';

ALERT_APP_WORLD_MOUSEMOVE = $40000;
ALERT_APP_WORLD_MOUSEMOVE_DLL = 'WorldMouseMove';
ALERT_APP_WORLD_MOUSEMOVE_CHARCODE = 243;

ALERT_APP_WORLD_MOUSEDOWN = $80000;
ALERT_APP_WORLD_MOUSEDOWN_DLL = 'WorldMouseDown';
ALERT_APP_WORLD_MOUSEDOWN_CHARCODE = 242;

ALERT_APP_WORLD_MOUSEUP = $100000;
ALERT_APP_WORLD_MOUSEUP_DLL = 'WorldMouseUp';
ALERT_APP_WORLD_MOUSEUP_CHARCODE = 241;

ALERT_APP_WORLD_END_REDRAW = $200000;
ALERT_APP_WORLD_END_REDRAW_DLL = 'WorldEndRedraw';
ALERT_APP_WORLD_END_REDRAW_CHARCODE = 240;

ALERT_APP_WORLD_BEGIN_REDRAW = $400000; 
ALERT_APP_WORLD_BEGIN_REDRAW_DLL = 'WorldBeginRedraw';
ALERT_APP_WORLD_BEGIN_REDRAW_CHARCODE = 239;

ALERT_APP_WORLD_BEGIN_PRINT = $800000;
ALERT_APP_WORLD_BEGIN_PRINT_DLL = 'WorldBeginPrint';
ALERT_APP_WORLD_BEGIN_PRINT_CHARCODE = 238;

ALERT_APP_WORLD_END_PRINT = $1000000; 
ALERT_APP_WORLD_END_PRINT_DLL = 'WorldEndPrint';
ALERT_APP_WORLD_END_PRINT_CHARCODE = 237;

{Added version 3.0.0}
ALERT_APP_TOOL_START = $2000000;  
ALERT_APP_TOOL_START_DLL = 'ToolStart';
ALERT_APP_TOOL_START_CHARCODE = 236;
{Added version 4.0.0
 encoded lParam which is sent with the alert 
 LOWORD = the ID of the tool being starting. See CmdID.h
 HIGHWORD = the tool type. See Visual CADD Tool Types.}

{Added version 3.0.0}
ALERT_APP_TOOL_ABORT = $4000000;  
ALERT_APP_TOOL_ABORT_DLL = 'ToolAbort';
ALERT_APP_TOOL_ABORT_CHARCODE = 235;
{Added version 4.0.0
 encoded lParam which is sent with the alert 
 LOWORD = the ID of the tool being starting. See CmdID.h
 HIGHWORD = the tool type. See Visual CADD Tool Types.}
 
{Visual CADD Tool Types}
{Added version 4.0.0
 The Visual CADD Tool Types flags sent as the lParam with
 the ALERT_APP_TOOL_START/COMPLETE/ABORT alerts.}
TOOL_NON_NESTABLE = 0;
TOOL_NESTABLE = 1;
TOOL_PHANTOM = 2;
TOOL_ALLOW_NON_NESTABLE = 3;

{======================================================================================
 Defines for VCSetAlertAppEx & VCSetAlertAppDllEx iCode1 Parameter Added version 3.0.0
 ======================================================================================}

ALERT_APP_EX_ALL = $FFFFFFFF;

{Added version 3.0.0}
ALERT_APP_EX_PRE_TRANSLATE_GET_MESSAGE = $1;
ALERT_APP_EX_PRE_TRANSLATE_GET_MESSAGE_DLL = 'PreTranslateGetMessage';
ALERT_APP_EX_PRE_TRANSLATE_GET_MESSAGE_CHARCODE = 233;

{Added version 3.0.0}
ALERT_APP_EX_PRE_TRANSLATE_FRAME_MESSAGE = $2;
ALERT_APP_EX_PRE_TRANSLATE_FRAME_MESSAGE_DLL = 'PreTranslateFrameMessage';
ALERT_APP_EX_PRE_TRANSLATE_FRAME_MESSAGE_CHARCODE = 232;

{Added version 3.0.0}
ALERT_APP_EX_PRE_TRANSLATE_DIALOG_MESSAGE = $4;
ALERT_APP_EX_PRE_TRANSLATE_DIALOG_MESSAGE_DLL = 'PreTranslateDialogMessage';
ALERT_APP_EX_PRE_TRANSLATE_DIALOG_MESSAGE_CHARCODE = 231;

{Added version 3.0.0}
{VCM_USER_ALERT Posted as the wParam of a WM_COMMAND Message will cause Visual CADD
 to call the ALERT_APP_EX_USER_ALERT_MESSAGE. The lParam the user sends in the WM_COMMAND
 message will be sent back to them. This call can be used to avoid recursion which can
 happen in many of the AlertApp messages such as starting a new tool from within the
 AlertAppToolComplete message.}
ALERT_APP_EX_USER_ALERT_MESSAGE = $8; 
ALERT_APP_EX_USER_ALERT_DLL = 'UserAlert';
ALERT_APP_EX_USER_ALERT_CHARCODE = 230;
VCM_USER_ALERT = 2801;

{Added version 3.0.1}
ALERT_APP_EX_DIALOG_OPEN_MESSAGE = $10;
ALERT_APP_EX_DIALOG_OPEN_DLL = 'DialogOpen';
ALERT_APP_EX_DIALOG_OPEN_CHARCODE = 229;

{Added version 3.0.1}
ALERT_APP_EX_DIALOG_CLOSE_MESSAGE = $20; 
ALERT_APP_EX_DIALOG_CLOSE_DLL = 'DialogClose';
ALERT_APP_EX_DIALOG_CLOSE_CHARCODE = 228;

{Added version 4.0.0}
ALERT_APP_EX_PRE_TRANSLATE_MDICHILD_MESSAGE = $40; 
ALERT_APP_EX_PRE_TRANSLATE_MDICHILD_MESSAGE_DLL = 'PreTranslateMdiChildMessage';
ALERT_APP_EX_PRE_TRANSLATE_MDICHILD_MESSAGE_CHARCODE = 227;

{Added version 5.0.0}
{ALERT_APP_EX_WORLD_ACTIVATE sends the
 THandle of the world just activated as the lParam.
 This alert is sent after the world has been activated.}
ALERT_APP_EX_WORLD_ACTIVATE = $80; 
ALERT_APP_EX_WORLD_ACTIVATE_DLL = 'WorldActivate';
ALERT_APP_EX_WORLD_ACTIVATE_CHARCODE = 226;

{Added version 5.0.0}
{ALERT_APP_EX_WORLD_DEACTIVATE sends the
 THandle of the world to be deactivated as the lParam.
 This alert is sent before the window is deactivated.}
ALERT_APP_EX_WORLD_DEACTIVATE = $100; 
ALERT_APP_EX_WORLD_DEACTIVATE_DLL = 'WorldDeActivate';
ALERT_APP_EX_WORLD_DEACTIVATE_CHARCODE = 225;

{Added version 5.0.0}
{ALERT_APP_EX_FILE_OPEN sends a flag indicating its
 state as the lParam.
 See ALERT_APP_EX_FILE_OPEN/FILE_SAVE alerts flags}
ALERT_APP_EX_FILE_OPEN = $200; 
ALERT_APP_EX_FILE_OPEN_DLL = 'FileOpen'; 
ALERT_APP_EX_FILE_OPEN_CHARCODE = 224;

{Added version 5.0.0}
{ALERT_APP_EX_FILE_SAVE sends a flag indicating its
 state as the lParam.
 See ALERT_APP_EX_FILE_OPEN/FILE_SAVE alerts flags}
ALERT_APP_EX_FILE_SAVE = $400; 
ALERT_APP_EX_FILE_SAVE_DLL = 'FileSave';
ALERT_APP_EX_FILE_SAVE_CHARCODE = 223;

{Added version 4.0.0}
{The Visual CADD Tool Types flags sent as the lParam with}
{the ALERT_APP_TOOL_START/COMPLETE/ABORT alerts.}
TOOL_NON_NESTABLE = 0;
TOOL_NESTABLE = 1;
TOOL_PHANTOM = 2;
TOOL_ALLOW_NON_NESTABLE = 3;

{Added version 5.0.0}
{The lParam flags sent with the ALERT_APP_EX_FILE_OPEN/FILE_SAVE alerts}
VC_FA_PRE_OPEN = 1;
VC_FA_POST_OPEN = 2;
VC_FA_PRE_DATA = 3;
VC_FA_POST_DATA = 4;
VC_FA_PRE_CLOSE = 5;
VC_FA_POST_CLOSE = 6;

{API calls which use "SymbolIndex", use this parameter for entity section additions}
{procedure VCAddLineEntityBP (var iError: SmallInt; iSymbolIndex: SmallInt; var dpP0: Point2D; var dpP1: Point2D); stdcall;
 iSymbolIndex = or iSymbolIndex = VCGetSymbolIndex(iError, pName);}
NONDEFENTITY = -1;
HATCHFILLENTITY = -2;

{procedure VCSetProjection3D (var iError: SmallInt; iCode: SmallInt); stdcall;
 iCode = }
VIEW3D_FLAT = 0;
VIEW3D_PARALLEL = 1;
VIEW3D_PERSPECTIVE = 2;

{procedure VCSet3DDisplay (var iError: SmallInt; iCode: SmallInt); stdcall;
 iCode = }
VIEW3D_WIREFRAME = 0;
VIEW3D_QSHADE = 1;

{procedure VCSet3DQShadeOptions (var iError: SmallInt; iCode: SmallInt); stdcall;
 iCode = }
QSHADE_ROUGH = 0;
QSHADE_EXACT = 1;
QSHADE_EXACT_AND_SPLIT = 2;

{procedure VCChangeView3D (var iError: SmallInt; iCode: SmallInt; dFact: Double); stdcall;
 iCode = }
CHANGE_VIEW3D_LEFT = 0;
CHANGE_VIEW3D_RIGHT = 1;
CHANGE_VIEW3D_UP = 2;
CHANGE_VIEW3D_DOWN = 3;

{VC Supported File Types}
{procedure VCSaveDrawing (var iError: SmallInt; pName: PAnsiChar; iFileType: SmallInt; tfSaveSelected: WordBool); stdcall;
 iFileType = }
FILE_NONVALID = -1;
FILE_VCD = 0;
FILE_VCS = 1;
FILE_VCA = 2;
FILE_GCD = 3;
FILE_CMP = 4;
FILE_DWG = 5;
FILE_DXF = 6;
FILE_STY = 7;
FILE_VCF = 8;
FILE_EMF = 9;
FILE_WMF = 10;
FILE_SHP = 11; {Added version 3.0.0}
FILE_MIF = 12; {Added version 3.0.0}
FILE_VBK = 13; {Added version 3.0.0}
FILE_PDF = 14; {Added version 5.0.0}
FILE_VBS = 15; {Added version 6.0.0}
FILE_JS = 16; {Added version 6.0.0}

{Conversion unit constants}
UNIT_INCH = 0;
UNIT_FEET = 1;
UNIT_MM = 2;
UNIT_CM = 3;
UNIT_M = 4;
UNIT_MILE = 10; {Added version 3.0.0}
UNIT_K = 11; {Added version 3.0.0}

{Display and dimension units}
{procedure VCSetDisplayDistFormat (var iError: SmallInt; iF_: SmallInt); stdcall;
 procedure VCSetDimDistFormat (var iError: SmallInt; iF_: SmallInt); stdcall;
 iF = }
InDec = 0;
FtInDec = 1;
FtDec = 2;
InFrac = 3;
FtInFrac = 4;
FtFrac = 5;
Mil = 6;
Cen = 7;
Met = 8;
Mile = 20;
Kilo = 21;

{Angular display and dimension units}
{procedure VCSetDisplayAngleFormat (var iError: SmallInt; iF_: SmallInt); stdcall;
 procedure VCSetDimAngleFormat (var iError: SmallInt; iF_: SmallInt); stdcall;
 iF = }
AngDeg = 9;
AngDMS = 10;
AngDM = 11;
AngRad = 12; {Added version 6.0.0}
AngGrad = 13; {Added version 6.0.0}
AngSurvey = 14; {Added version 6.0.0}

{Dimension mode}
{procedure VCDimSetDimMode (var iError: SmallInt; b: SmallInt); stdcall;
 b = }
DIMMODESINGLE = 0;
DIMMODECUMULATIVE = 1;
DIMMODEPARTITIONED = 2;

{Dimension Direction}
{procedure VCSetDimLineDirect (var iError: SmallInt; b: SmallInt); stdcall;
 b = }
DIMALIGNED = 1;
DIMHORIZONTAL = 2;
DIMVERTICAL = 3;
DIMATANANGLE = 4;

{Tolerance Type}
{procedure VCSetDimTextTolType (var iError: SmallInt; b: SmallInt); stdcall;
 b = }
DIMNOTOLERANCE = 0;
DIMSTACKEDMINMAX = 1;
DIMSTACKEDVARIANCE = 2;
DIMFIXEDVARIANCE = 3;
DIMBASICTOLERANCE = 4;

{Dimension Extension Stretch}
{procedure VCDimSetDimExtStretch (var iError: SmallInt; b: SmallInt); stdcall;
 b = }
DIMEXTNOSTRETCH = 0;
DIMEXTSTRETCH = 1;

{Arrow Types}
{procedure VCSetDimArrowType (var iError: SmallInt; b: SmallInt); stdcall;
 b = }
DIMARROWREGNOFILL = 0;
DIMARROWREGFILLED = 1;
DIMARROWREGOPEN = 2;
DIMARROWNOTCHED = 3;
DIMARROWSLASH = 4;
DIMARROWCIRCLENOFILL = 5;
DIMARROWCIRCLEFILL = 6;

{Dimension Text Position}
{procedure VCSetDimLineText (var iError: SmallInt; b: SmallInt); stdcall;
 b = }
DIMTEXTINLINE = 0;
DIMTEXTABOVELINE = 1;
DIMTEXTFREEFLOAT = 2;
DIMTOUTSIDELINE = 3; {Added version 4.0.0}
DIMTEXTINLINE_CENTER = 4; {Added version 8.0.0}

{Dimension Text Rotation}
{procedure VCSetDimTextRotationType (var iError: SmallInt; b: SmallInt); stdcall;
 b = }
DIMTEXTROTATIONALIGNED = 0;
DIMTEXTROTATIONHORIZONTAL = 1;

{Dimension Proximity Mode}
{procedure VCDimSetDimProximity (var iError: SmallInt; b: SmallInt); stdcall;
 b = }
DIMLINENOPROXFIX = 0;
DIMLINEPROXFIX = 1;

{Arrow Mode}
{procedure VCSetDimArrowMode (var iError: SmallInt; b: SmallInt); stdcall;
 b = }
DIMARROWNOFLIP = 0;
DIMARROWFLIP = 1;

{Dimension items}
{procedure VCSetDimItemColor (var iError: SmallInt; i: SmallInt; j: SmallInt); stdcall;
 i = }
DIMLINE = 0;
DIMLEFTARROW = 1;
DIMRIGHTARROW = 2;
DIMLEFTEXT = 3;
DIMRIGHTEXT = 4;
DIMTEXT = 5;

{Added version 6.0.0}
{Dimension angle styles}
DIMANGLESTYLE_DEFAULT = 0;
DIMANGLESTYLE_ANGLEFIRST = 1;
DIMANGLESTYLE_ANGLELAST = 2;
DIMANGLESTYLE_ANGLEONLY = 3;

{Added version 9.0.0}
{Dimension decimal separators}
DIM_DECIMAL_SEPARATOR_PERIOD = 0;
DIM_DECIMAL_SEPARATOR_COMMA = 1;
DIM_DECIMAL_SEPARATOR_MIDDLE_DOT = 2;
DIM_DECIMAL_SEPARATOR_APOSTROPHE = 3;

{Added version 9.0.0}
{Dimension thousands separators}
DIM_THOUSANDS_SEPARATOR_NONE = 0;
DIM_THOUSANDS_SEPARATOR_COMMA = 1;
DIM_THOUSANDS_SEPARATOR_SPACE = 2;
DIM_THOUSANDS_SEPARATOR_PERIOD  3;
DIM_THOUSANDS_SEPARATOR_APOSTROPHE = 4;
DIM_THOUSANDS_SEPARATOR_UNDERSCORE = 5;

{Added version 6.0.0}
{Leader vertical alignments}
{procedure VCSetLeaderVerticalAlign (var iError: SmallInt; b: Byte); stdcall;
 b = }
LEADER_VERT_DEFAULT = 0;
LEADER_VERT_BASELINE = 1;
LEADER_VERT_TOP = 2;
LEADER_VERT_CENTER = 3;
LEADER_VERT_BOTTOMCENTER = 4;
LEADER_VERT_BOTTOMBASELINE = 5;

{Added version 8.0.0}
{Text vertical alignments}
{extern "C" void WINAPI VCSetTextVerticalAlign(short* iError, BYTE b);}
{b =}
TEXT_VERT_DEFAULT = 1;
TEXT_VERT_TOPCENTER = 0;
TEXT_VERT_BASELINE = 1;
TEXT_VERT_TOP = 2;
TEXT_VERT_CENTER = 3;
TEXT_VERT_BOTTOMCENTER = 4;
TEXT_VERT_BOTTOMBASELINE = 5;

{Added version 8.0.0}
{Text position}
{extern "C" void WINAPI VCSetLeaderHorizontalAlign(short* iError, BYTE b);}
{b =}
LEADER_HORZ_DEFAULT = 0;
LEADER_HORZ_LEFT = 1;
LEADER_HORZ_RIGHT = 2;
LEADER_HORZ_CENTER = 3;

{Added version 6.0.0}
{Leader borders}
LEADER_BORDER_BOX = 0;
LEADER_BORDER_CIRCLE_FIX = 1;
LEADER_BORDER_CIRCLE_VAR = 2;
LEADER_BORDER_VLINE = 3;
LEADER_BORDER_HLINE = 4;

{Added version 6.0.0}
{Leader items}
LEADERTEXT = 0;
LEADERLINE = 1;
LEADERARROW = 2;
LEADERBORDER = 3;

{Datum modes}
{procedure VCSetDatumType (var iError: SmallInt; iDatumType: SmallInt); stdcall;
 iDatumType = }
DATUMNONE = 0;
DATUMXY = 1;
DATUMX = 2;
DATUMY = 3;

{Text justify modes}
{procedure VCSetTextJustify (var iError: SmallInt; j: SmallInt); stdcall;
 j = }
JUSTIFY_CENTER = 67;	{ASCII character C}
JUSTIFY_LEFT = 76;	{ASCII character L}
JUSTIFY_RIGHT = 82;	{ASCII character R}

{Symbol explode layers}
{procedure VCSetSymExplode (var iError: SmallInt; iEx: SmallInt); stdcall;
 iEx = }
INDIVIDUAL_LAYER = 0;
PLACEMENT_LAYER = 1;
CURRENT_LAYER = 2;

{AutoCAD Import Unit Types}
{procedure VCSetAcadImportUnit (var iError: SmallInt; b: Byte); stdcall;
 b = }
ACAD_UNIT_INCH = 0;
ACAD_UNIT_FEET = 1;
ACAD_UNIT_MILL = 2;
ACAD_UNIT_CENT = 3;
ACAD_UNIT_METER = 4;

{Printer API constants}

{PrintStruct.tfPrintMode = }
PRINTMODE = 0;
PLOTMODE = 1;

{PrintStruct.ScaleMode = }
FITTOPAPER = 1;
CURRENTVIEW = 2;
SCALE = 3;

{PrintStruct.Orientation = }
PORTRAITMODE = 0;
LANDSCAPEMODE = 1;

{PrintStruct.PaperUnit = }
METRICUNITS = 0;
ENGLISHUNITS = 1;

{Used in PrintStruct}
Type
DoubleRect=record
	Left: Double;
	Top: Double;
	Right: Double;
	Bottom: Double;
end;

{procedure VCSetPrintSettings (var iError: SmallInt; var pSettings: PrintStruct); stdcall;
 PrintStruct = }
Type
PrintStruct=record
	PrintMode: wordbool;
	PageSize: Point2D;
	Margins: DoubleRect;
	dScale: Double;
	Origin: Point2D;
	ScaleMode: SmallInt;
	Orientation: SmallInt;
	dRotation: Double;
	PrintToFile: wordbool;
	SelectionOnly: wordbool;
	DateStamp: wordbool;
	FastPreview: wordbool;
	AllColorsToBlack: wordbool;
	PaperUnit: SmallInt;
end;

{Plotter API constants}

Const
{PlotStruct.Port = }
PORTCOM1 = 0;
PORTCOM2 = 1;
PORTCOM3 = 2;
PORTCOM4 = 3;
PORTLPT1 = 4;
PORTLPT2 = 5;
PORTLPT3 = 6;
PORTFILE = 7;

{PlotStruct.BaudRate = }
BAUD110 = 0;
BAUD300 = 1;
BAUD1200 = 2;
BAUD2400 = 3;
BAUD4800 = 4;
BAUD9600 = 5;
BAUD19200 = 6;
BAUD38400 = 7;
BAUD57600 = 8;

{PlotStruct.DataBits = }
DATABITS7 = 0;
DATABITS8 = 1;

{PlotStruct.Parity = }
PARITYODD = 0;
PARITYEVEN = 1;
PARITYNONE = 2;

{PlotStruct.StopBits = }
STOPBITS1 = 0;
STOPBITS2 = 1;

{procedure VCSetPlotSettings (var iError: SmallInt; var pSettings: PlotStruct); stdcall;
 pSettings = }
Type
PlotStruct=record
	Port: SmallInt;
	BaudRate: SmallInt;
	DataBits: SmallInt;
	Parity: SmallInt;
	StopBits: SmallInt;
	NumPens: SmallInt;
	NumCarousels: SmallInt;
	DPI: SmallInt;
	UseCarousels: wordbool;
	UseLLOrigin: wordbool;
	SortColors: wordbool;
	Optimize: wordbool;
	BufferOutput: wordbool;
end;

{Tool Bar constants}
{function VCGetToolbar (i: SmallInt): THandle; stdcall;
 i = }
Const
TBNONE = 0;		{no toolbar}
TBTOP = 1;		{the main speedbar}
TBLEFT = 2;		{the tool palette}
TBRIGHT = 3;	{not used}
TBBOTTOM = 4; {the status bar}

{Font types constants}
{procedure VCSetTextFontNameAndType (var iError: SmallInt; pS: PAnsiChar; b: Byte); stdcall;
 b = }
WINTEXT = $0; {Windows font}
VCFTEXT = $1; {VCF font}
LIMBOTEXT = $2; {undetermined font Added version 5.0.0}
LOOKUPTEXT = $4; {lookup font type in font table Added version 5.0.0}

{Added version 4.0.0}
{Ortho Advanced type flags}
{procedure VCSetOrthoAdvancedType (var iError: SmallInt; iType: SmallInt); stdcall;
 iType = }
ORTHOADV_NONE = 0;
ORTHOADV_STEPANGLE = 1;
ORTHOADV_INCREMENTS = 2;
ORTHOADV_ONEANGLE = 3;

{Added version 4.0.0}
{Running snap type flags}
{procedure VCSetRunningSnapType (var iError: SmallInt; dwFlags: LongWord; wOperation: Word); stdcall;
 dwFlags = }
NOSNAP = $0;
OSNAP_END = $1;
OSNAP_OBJ = $2;
OSNAP_MID = $4;
OSNAP_INT = $8;
OSNAP_PERP = $10;
OSNAP_TAN = $20;
OSNAP_QUAD = $40;
OSNAP_PER = $80;
OSNAP_CEN = $100;
OSNAP_GRID = $200; {Added version 8.0.0}
OSNAP_ALL = $3FF; {This will be updated if new snaps are added}

{Added version 4.0.0}
{Running snap types bitwise operators}
{procedure VCSetRunningSnapType (var iError: SmallInt; dwFlags: LongWord; wOperation: Word); stdcall;
 wOperation = }
Op_Assign = 1;
Op_OR = 2;
Op_AND = 3;
Op_Restore = 4; {Added version 7.0.0}

{Added version 4.0.0}
{Font list sorting order flags}
{procedure VCSetFontListSorting (var iError: SmallInt; i: SmallInt); stdcall;
 i = }
SORT_ALLFONTS_MIXED = 0;
SORT_VECTORFONT_FIRST = 1;
SORT_TRUETYPEFONT_FIRST = 2;

{Added version 5.0.0}
{status codes on completion of HatchGen}
{function VCGetCurrentHatchStatus (var iError: SmallInt): LongInt; stdcall;}
GENERATE_NOT_DONE = 0;
GENERATE_NORMAL = 1;
GENERATE_USER_ABORT = 2;
GENERATE_MAX_EXCEEDED = 3;
GENERATE_HATCH_NOT_FOUND = 4;
GENERATE_INVALID_BOUNDARY = 5;
GENERATE_NO_DRAWPATTERN = 6;

{Added version 5.0.0}
{Hatch alignment flags}
{procedure VCSetHatchAlignment (var iError: SmallInt; iAlign: LongInt); stdcall;
 iAlign = }
HATCH_ALIGN_CENTER = 0;
HATCH_ALIGN_ORIGIN = 1;
HATCH_ALIGN_LOWER_LEFT = 2;
HATCH_ALIGN_FIRST_POINT = 3;

{Added version 5.0.0}
{Sound event flags}
{procedure VCSound (Sound: LongWord); stdcall;
 Sound = }
SND_CRITICAL = $1000000;	{critical error}
SND_TOOLERROR = $2000000; {tool error}
SND_TOOLDONE = $3000000;	{successful tool completion}
SND_ABORT = $4000000;			{abort}
SND_ALERT = $5000000;			{user attention is required}
SND_INPUT = $6000000;			{input error}
SND_DEBUG = $7000000;			{internal debug sound}
SND_STARTUP = $8000000;		{start up sound}
SOUND_COUNT = 8;		{updated as needed}

{Added version 5.0.0}
{EraseEx action flags}
{function VCSetCurrentErasedEx (var iError: SmallInt; iErase: SmallInt; iUserSessionID: SmallInt; bfFlags: LongWord): WordBool; stdcall;
 iErase = }
EREX_UNERASE = 0;
EREX_ERASE = 1;
EREX_ERASE_NOREDO = 2;
EREX_PURGE = 3;

{Added version 5.0.0}
{OperationEx and EraseEx behaviour flags}
{function VCSetCurrentErasedEx (var iError: SmallInt; iErase: SmallInt; iUserSessionID: SmallInt; bfFlags: LongWord): WordBool; stdcall;
 function VCEndOperationEx (var iError: SmallInt; iUserSessionID: SmallInt; bfFlags: LongWord): SmallInt; stdcall;
 bfFlags = }
OPEX_DEFAULT = $0;
OPEX_NOTRUNC = $1;
OPEX_NOPURGE = $2;
OPEX_NODESELECT = $4;
OPEX_NODRAW = $8;

{The following are not used directly in the API but can be useful in Visual CADD programming}

{Visual CADD Fonts}

{TrueType font ASCII Character Code values for dimension symbols}
TT_DIAMETER_SYMBOL = 216;
TT_PLUSMINUS_SYMBOL = 177;
TT_DEGREE_SYMBOL = 176;

{VCF font ASCII Character Code values for dimension symbols}
VCF_DIAMETER_SYMBOL = 157;
VCF_PLUSMINUS_SYMBOL = 241;
VCF_DEGREE_SYMBOL = 248;

{Used in VCFCharRecord}
Type
fPoint2D=record
  x: single;
  y: single;
end;

{VCF font record}
Type
VCFCharRecord=record
  ch: Byte;
  bFillable: SmallInt;
  fpMin: fPoint2D;
  fpMax: fPoint2D;
end;

{VCF font header}
Type
VCFHeader=record
  bVersion: Byte;
  szFont: array[0..32] of AnsiChar;
  nChars: SmallInt;
end;

{Added version 5.0.0}
{PDF export settings}
Type
VCPDFExportSettings = record
	iSize: SmallInt; {size of this structure (v5 = 1270, v6 = 1278)}
	dHeight: Double; {output "paper" height, in inches}
	dWidth: Double; {output "paper" width, in inches}
	dpMarginUR: Point2D; {top and right margins, in inches}
	dpMarginLL: Point2D; {bottom and left margins, in inches}

	tfUseCompression: Wordbool; {use PDF compression}
	tfSelectionOnly: Wordbool; {only include selected entities in output}
	tfLW0HasWidth: Wordbool; {treat LW0 as LW1}
	tfCenterAlways: Wordbool; {always center output on page}
	tfLandscape: Wordbool; {use landscape mode}
	tfShowWatermark: Wordbool; {display watermark}

	iOutputColor: SmallInt; {0 for include color, non-zero for all colors black}
	iFontEmbed: SmallInt; {0 for don't embed, 1 for embed}

	iPermissions: SmallInt; {desired permissions}
	tfUseEncryption: Wordbool; {encrypt PDF output}
	szUserPwd[36]: array[0..35] of AnsiChar; {NOTE: passwords are 32 chars + NULL, padded to 36 to maintain structure packing}
	szOwnerPwd[36]: array[0..35] of AnsiChar;}
	szWatermark[64]: array[0..63] of AnsiChar; {watermark string}

	szTitle[256]: array[0..255] of AnsiChar; {title string in document properties}
	szSubject[256]: array[0..255] of AnsiChar; {subject string in document properties}
	szAuthor[256]: array[0..255] of AnsiChar; {author string in document properties}
	szKeywords[256]: array[0..255] of AnsiChar; {keyword string in document properties}

	dBaseLineWidth: Double; {width of a LW1 line}

	dpOrigin: Point2D; {location on output of the LL corner of the extents of the output entities}
	iView: SmallInt; { 1=fit 2=curr View 3=Scale}
	dScale: Double; {output inches/drawing inch}
	tfOpenReader: Wordbool; {open PDF reader when output complete}
	iImageResolution: LongInt; {OLE bitmap resolution in DPI}
	{v6.0 and later}
	iLayerMode: LongInt; {Layer export mode (0 = none, 1 = visible, 2 = printable)}
	iWatermarkGray: LongInt; {Watermark gray density (0-100%)  }
end;

{Visual CADD cursor names}
{These can be used to load Visual CADD cursors for use in your application.
 Example: hLikeCur = LoadCursor(VCGetVCResourceInstance(), CUR_LIKECURSOR);}
Const
CUR_LIKECURSOR = 'LIKECURSOR';
CUR_POINTER = 'POINTER';
CUR_NOCURSOR = 'NOCURSOR';
CUR_MOVECURSOR = 'MOVECURSOR';
CUR_SNAPEND = 'SNAPEND';
CUR_SNAPCENTER = 'SNAPCENTER';
CUR_SNAPINT = 'SNAPINT';
CUR_SNAPOBJ = 'SNAPOBJ';
CUR_SNAPMID = 'SNAPMID';
CUR_SNAPPERCENT = 'SNAPPERCENT';
CUR_SNAPPERP = 'SNAPPERP';
CUR_SNAPQUAD = 'SNAPQUAD';
CUR_SNAPGRID = 'SNAPGRID';
CUR_SNAPTAN = 'SNAPTAN';
CUR_DRAGDOC = 'DRAGDOC';
CUR_DRAGDATA = 'DRAGDATA';
CUR_SIZEWE = 'SIZEWE';
CUR_TOLAYER = 'TOLAYER';

{Visual CADD limits}

{The following string length are the sizes of the maximum string
 sizes and do not include space for the terminal NULL. Buffer to
 receive these values need to be sized accordingly.
 Example: szBuffer[MAX_MACRO + 1]}
MAX_VC_OBJ_NAME = 32;
MAX_VC_SYM_NAME = MAX_VC_OBJ_NAME;
MAX_VC_ATB_NAME = MAX_VC_OBJ_NAME;
MAX_VC_HATCH_NAME = MAX_VC_OBJ_NAME;
MAX_VC_LAY_NAME = MAX_VC_OBJ_NAME;
MAX_VC_LAY_GRP_NAME = MAX_VC_LAY_NAME;
MAX_VC_COLOR_NAME = MAX_VC_OBJ_NAME;
MAX_VC_LTYPE_NAME = MAX_VC_OBJ_NAME;
MAX_VC_VIEW_NAME = MAX_VC_OBJ_NAME;

MAX_NATIVE_NAME = 12;
MAX_SHORTCUT = 3;
MAX_DESCRIPTION = 128;
MAX_MACRO = 32000; {Changed from 255 in version 4.0.0}

MAX_VC_RWLWIDTH_STRING = 25;
MAX_VC_DIM_STRING = 347;

{Visual CADD Layers}
MAX_VCADD_LAYERS = 1024;
MAX_VCADD_LAYERS_INDEX = (MAX_VCADD_LAYERS - 1);
MIN_VCADD_LAYERS_INDEX = 0;

{Visual CADD Colors}
MAX_VCADD_COLORS = 256;
MAX_VCADD_COLOR_INDEX = (MAX_VCADD_COLORS - 1);
MIN_VCADD_COLOR_INDEX = 0;
MAX_SYSTEM_COLOR_INDEX = 15; {Cursor and other system setting with a limited color pallet}

{Visual CADD LineTypes}
MAX_VCADD_LTYPES = 256;
MAX_VCADD_LTYPES_INDEX = (MAX_VCADD_LTYPES - 1);
MIN_VCADD_LTYPES_INDEX = 0;

{Visual CADD LineWidths}
MAX_VCADD_LWIDTHS = 16;
MAX_VCADD_LWIDTHS_INDEX = (MAX_VCADD_LWIDTHS - 1);
MIN_VCADD_LWIDTHS_INDEX = 0;

{maximum number of points in a continuous entity (CONTINUOUSLINE2D, CONTINUOUSBEZIER2D, MINTERPCURV2D, MULTILINE2D)}
MAX_CONTINUOUS_POINTS = 3748;

MAX_VC_ATB_FIELD = 128;
MAX_VC_ATB_FIELDNAME = 79;

{Mathematical constants}

{PI defines}
PI = 3.14159265358979323846;
TWOPI = (2.0 * PI);
HALFPI = 1.57079632679489661923;

MYRADIAN = (180.0 / PI);

{Radian degrees}
{DegreeToRadian(d) = (d / 180.0 * PI)}
{RadianToDegree(r) = (r / PI * 180.0)}

{Standard angles}
A15 = (15.0 / MYRADIAN);
A30 = (30.0 / MYRADIAN);
A45 = (45.0 / MYRADIAN);
A90 = (HALFPI);
A135 = (135.0 / MYRADIAN);
A150 = (150.0 / MYRADIAN);
A210 = (210.0 / MYRADIAN);
A270 =(3.0 * HALFPI);
A315 = (315.0 / MYRADIAN);
A330 = (330.0 / MYRADIAN);

{Unit conversion definitions}
MM_PER_INCH = 25.4;
INCHES_PER_INCH = 1.0;
INCHES_PER_FOOT = 12.0;
INCHES_PER_MILE = 63360.0;

INCHES_PER_MM = (1.0 / MM_PER_INCH);
INCHES_PER_CM = (10.0 / MM_PER_INCH);
INCHES_PER_METER = (1000.0 / MM_PER_INCH);
INCHES_PER_KILOMETER = (1000000.0 / MM_PER_INCH);

FEET_PER_INCH = (INCHES_PER_INCH / INCHES_PER_FOOT);
MILES_PER_INCH = (INCHES_PER_INCH / INCHES_PER_MILE);
CM_PER_INCH = (MM_PER_INCH / 10.0);
METERS_PER_INCH = (MM_PER_INCH / 1000.0);
KILOMETERS_PER_INCH = (MM_PER_INCH / 1000000.0);

{Added version 6.0.0}
{File Locking}
MAX_VC_LOC_USERNAME = 274; {MAX_COMPUTERNAME_LENGTH + UNLEN + 3}

VCLF_SAVING = 1;
VCLF_SILENT = 2;
VCLF_LOCKALWAYS = 4;
VCLF_NOLOCK = 8;
VCLF_READWRITE = 16;

{Added version 6.0.0}
{function VCOnPreTranslateMessage (var pMsg: MSG): BOOL; stdcall;}
Type
MSG=Record
	hwnd: LongWord;
	message: LongWord;
	wParam: LongWord;
	lParam: LongInt;
	time:LongWord;
	pt:TPoint;
end;

IEX_BMP = 0;
IEX_JPG = 1;
IEX_TIF = 2;
IEX_PNG = 3;
IEX_EMF = 4;
IEX_WMF = 5;
IEX_GIF = 6;

IEX_BMP_MODE_BW = 0;  {Black on white}
IEX_BMP_MODE_WB = 1;  {White on black}
IEX_BMP_MODE_8 = 2;  {256 Colors (8 bit)}
IEX_BMP_MODE_16 = 3;  {65k Colors (16 bit)}
IEX_BMP_MODE_24 = 4;  {16.7M Colors (24 bit)}

IEX_JPG_MODE_8 = 0;  {8 bit grayscale}
IEX_JPG_MODE_RGB = 1;  {24 bit RGB}
IEX_JPG_MODE_CYMK = 2;  {32 bit CMYK}

IEX_TIF_MODE_BW = 0;  {Black on white}
IEX_TIF_MODE_WB = 1;  {White on black}
IEX_TIF_MODE_8 = 2;  {256 Colors (8 bit)}
IEX_TIF_MODE_24 = 3;  {16.7M Colors (24 bit RGB)}
IEX_TIF_MODE_32 = 4;  {16.7M Colors (32 bit RGBA)}

IEX_PNG_MODE_BW = 0;  {Black on white}
IEX_PNG_MODE_WB = 1;  {White on black}
IEX_PNG_MODE_GRAY = 2;  {Grayscale (8 bit)}
IEX_PNG_MODE_MAP = 3;  {256 Colors (8 bit)}
IEX_PNG_MODE_RGB = 4;  {16.7M Colors(24 bit RGB)}
IEX_PNG_MODE_RGBA = 5;  {16.7M (32 bit RGBA)}

IEX_EMF_MODE_NONE = 0;  {No background}
IEX_EMF_MODE_BACK = 1;  {Include Background}

IEX_GIF_MODE_8 = 0;  {8 Bit with palette}

IEX_BMP_COMP_0 = 0;  {None}
IEX_BMP_COMP_1 = 1;  {RLE}

IEX_JPG_COMP_0 = 0;  {Low}
IEX_JPG_COMP_1 = 1;  {Medium}
IEX_JPG_COMP_2 = 2;  {High}

IEX_TIF_COMP_0 = 0;  {None}
IEX_TIF_COMP_1 = 1;  {CCITT}
IEX_TIF_COMP_2 = 2;  {JPEG}
IEX_TIF_COMP_3 = 3;  {PackBits}
IEX_TIF_COMP_4 = 4;  {Deflate}


{Configuration file translation type constants}
#define	CFT_SCRIPT = 1; {Script.def}
#define	CFT_CMDEXT = 2; {Cmdext.def}
#define	CFT_MENU	 = 3; {Menu (.mnu) files}
#define	CFT_HATCH	 = 4; {Hatches.hat}
#define	CFT_MULTILINE = 5; {Multiline styles}
#define	CFT_PRESETS = 6; {Print presets}
#define	CFT_PDF = 7; {PDF presets}
#define	CFT_PLOT = 8; {Plot settings}
#define	CFT_LINETYPE = 9; {Linetype.lnt}
#define	CFT_VGAPAL = 10; {VGA.pal}
#define	CFT_TOOLBAR = 11; {Toolbars (.mbr, .tbr)}
#define	CFT_MOUSEMNU = 12; {MouseMenu.def}
#define	CFT_POPUP = 13; {Popup (.pop) files}

{Added version 7.0.2}
{  user data constants}
USER_UNKNOWN = 0;
USER_BYTE = 1;
USER_SHORT = 2;
USER_LONG = 3;
USER_DOUBLE = 4;
USER_FLOAT = 5;
USER_CHUNK = 6;
USER_STRING = 7;
USER_NUMERIC = 8; {Added 8.0.0}
USER_TEXT = 9; {Added 8.0.0}

USER_NAME_SIZE = 16;
USER_MAX_CHUNK_SIZE = 1024;
USER_MAX_STRING_SIZE = 255;

{Added version 7.0.3}
{ Floating edit dialog constants}
FLTDLG_NEVER = 0;
FLTDLG_CREATE = 1;
FLTDLG_EDIT = 2;
FLTDLG_ALWAYS = 3;

{Added version 8.0.0}
{Status bar user pane constants and data structure}
SBUP_MASK_TEXT = $1;
SBUP_MASK_COLOR = $2;
SBUP_MASK_BACK = $4;

SBUP_ACTION_UPDATE = 0;
SBUP_ACTION_LBUTTON = 1;
SBUP_ACTION_RBUTTON = 2;

{Added version 9.0.0}
{User tool flags}
USERTOOL_IS_NESTED = $1;
USERTOOL_IS_SNAP = $2;
USERTOOL_USES_RUNNING_SNAPS = $4;
USERTOOL_PASSTRHU_MOUSEMOVE = $8;
USERTOOL_PASSTRHU_RUBBERSTATE = $10;

{Added version 9.0.0}
{Status bar message colors}
STATUSCOLOR_NORMAL = 0;
STATUSCOLOR_WARNING = 1;
STATUSCOLOR_LOCKED = 2;

implementation

end.
